@@ -107,6 +107,9 @@ pub fn pbenchmark(args: &mut env::Args) -> Result<(), PConvertError> {
         _ => false,
     };
 
+    // prints the header information of the table with all
+    // of the columns set to the same size, then prints a
+    // simple line separator
     println!(
         "{:<20}{:<20}{:<20}{:<20}",
         "Algorithm", "Compression", "Filter", "Times"
@@ -123,7 +126,7 @@ pub fn pbenchmark(args: &mut env::Args) -> Result<(), PConvertError> {
                 if run_parallel {
                     compose_parallel(
                         &dir,
-                        BlendAlgorithm::from_str(&algorithm).unwrap(),
+                        BlendAlgorithm::from_str(algorithm).unwrap(),
                         &Background::Alpha,
                         *compression,
                         *filter,
@@ -132,7 +135,7 @@ pub fn pbenchmark(args: &mut env::Args) -> Result<(), PConvertError> {
                 } else {
                     compose(
                         &dir,
-                        BlendAlgorithm::from_str(&algorithm).unwrap(),
+                        BlendAlgorithm::from_str(algorithm).unwrap(),
                         &Background::Alpha,
                         *compression,
                         *filter,
@@ -140,12 +143,11 @@ pub fn pbenchmark(args: &mut env::Args) -> Result<(), PConvertError> {
                     )?;
                 }
 
+                let compression = format!("{:#?}", compression);
+                let filter = format!("{:#?}", filter);
                 println!(
                     "{:<20}{:<20}{:<20}{:<20}",
-                    algorithm,
-                    format!("{:#?}", compression),
-                    format!("{:#?}", filter),
-                    &benchmark
+                    algorithm, compression, filter, &benchmark
                 );
                 total_benchmark = total_benchmark + benchmark;
             }
@@ -168,5 +170,5 @@ pub fn pversion() {
         constants::LIBPNG_VERSION,
         constants::FEATURES
     );
-    println!("Copyright (c) 2008-2021 Platforme International Limited. All rights reserved.");
+    println!("Copyright (c) 2008-2022 Platforme International Limited. All rights reserved.");
 }
